TimePointError

Enum TimePointError 

pub enum TimePointError {
    Alphabet(AlphabetError),
    Series(SeriesError),
    SystemMismatch {
        expected: NonZeroU16,
        found: NonZeroU16,
    },
    PointOutsideSystem {
        point: u16,
        modulus: NonZeroU16,
    },
}
Failure while constructing or realizing exact time-point data.

Variants



Alphabet(AlphabetError)

The canonical onset-class alphabet was invalid.



Series(SeriesError)

The caller-supplied onset-class order violated the system aggregate contract.



SystemMismatch

The caller tried to realize a row under another modulus.

Fields

expected: NonZeroU16

Row modulus retained by the row alphabet.

found: NonZeroU16

Realization modulus supplied by the caller.



PointOutsideSystem

One onset class lay outside the selected finite system.

Fields

point: u16

Rejected onset class.

modulus: NonZeroU16

Finite system modulus.