BuiltInPracticeRule

Struct BuiltInPracticeRule 

pub struct BuiltInPracticeRule { /* private fields */ }
Built-in inspectable rule implementations for common serial-practice checks.

Implementations

Source

impl BuiltInPracticeRule

pub fn aggregate(id: PracticeRuleId) -> Self

Requires every structural ordinal to appear exactly once under the reading.

pub fn order(id: PracticeRuleId) -> Self

Requires first structural appearances to remain in row order.

pub fn repeats(id: PracticeRuleId) -> Self

Forbids repeated ordinal references under the reading.

pub fn doublings(id: PracticeRuleId) -> Self

Forbids simultaneous doublings of one row pitch class.

pub fn simultaneity(id: PracticeRuleId, allow: bool) -> Self

Controls whether simultaneous groups are accepted.

pub fn row_mixing(id: PracticeRuleId) -> Self

Forbids one event from mixing ordinals from multiple row instances.

pub fn foreign_material(id: PracticeRuleId, allow_external: bool) -> Self

Controls whether externally sourced material is accepted.

pub fn parameter_exhaustion(id: PracticeRuleId) -> Self

Requires non-structural reuse after full aggregate exposure to be declared as a relaxation.