pub struct InvariantLedger<R> { /* private fields */ }Expand description
Complete invariant bundle for one selected reading.
Implementations
Sourceimpl<R> InvariantLedger<R>
impl<R> InvariantLedger<R>
Sourcepub fn new(entries: Vec<InvariantLedgerEntry<R>>) -> Self
pub fn new(entries: Vec<InvariantLedgerEntry<R>>) -> Self
Creates one immutable invariant ledger.
Sourcepub fn entries(&self) -> &[InvariantLedgerEntry<R>]
pub fn entries(&self) -> &[InvariantLedgerEntry<R>]
Returns the recorded invariant entries in stable rule order.
Sourcepub fn is_preserved(&self, invariant_id: &str) -> bool
pub fn is_preserved(&self, invariant_id: &str) -> bool
Returns true when the named invariant is present and preserved.
Sourcepub fn is_relaxed(&self, invariant_id: &str) -> bool
pub fn is_relaxed(&self, invariant_id: &str) -> bool
Returns true when the named invariant is present and relaxed.