pub struct ParameterSeries<T: ParameterValue> { /* private fields */ }Expand description
Thin typed wrapper over an unchanged serial-core Series.
Implementations
Sourceimpl<T: ParameterValue> ParameterSeries<T>
impl<T: ParameterValue> ParameterSeries<T>
Sourcepub fn try_new(
id: impl Into<String>,
order: Vec<T>,
) -> Result<Self, ParameterError>
pub fn try_new( id: impl Into<String>, order: Vec<T>, ) -> Result<Self, ParameterError>
Constructs one exhaustive exactly-once parameter series.
Sourcepub fn try_new_with_rule(
id: impl Into<String>,
rule: AggregateRule,
order: Vec<T>,
) -> Result<Self, ParameterError>
pub fn try_new_with_rule( id: impl Into<String>, rule: AggregateRule, order: Vec<T>, ) -> Result<Self, ParameterError>
Constructs one parameter series under an explicit aggregate rule.
Sourcepub fn alphabet(&self) -> &ParameterAlphabet<T>
pub fn alphabet(&self) -> &ParameterAlphabet<T>
Returns the retained generic parameter alphabet.
Sourcepub fn rule(&self) -> &AggregateRule
pub fn rule(&self) -> &AggregateRule
Returns the unchanged aggregate rule carried by the series.
Sourcepub fn ledger(&self) -> &AggregateLedger<T>
pub fn ledger(&self) -> &AggregateLedger<T>
Returns the source aggregate ledger retained by serial-core.
Sourcepub fn apply(
&self,
transform: &SeriesTransform<ParameterAlphabet<T>>,
) -> Result<Self, ParameterError>
pub fn apply( &self, transform: &SeriesTransform<ParameterAlphabet<T>>, ) -> Result<Self, ParameterError>
Applies one serial-core transform and returns a new typed parameter series.