pub struct SerialCompletionAllowances {
pub current_partition: bool,
pub stated_pitch_classes: bool,
pub aggregate_remainder: bool,
pub referential_subsets: Vec<ReferentialSubsetAllowance>,
pub modal_projection: bool,
pub derived_reservoir: bool,
pub explicitly_foreign_material: bool,
}Expand description
Admission policy layered over generic completion candidates.
Fields
current_partition: boolAdmit notes that reuse the current structural partition.
stated_pitch_classes: boolAdmit notes that reuse already stated structural pitch classes.
aggregate_remainder: boolAdmit notes that borrow a future structural remainder pitch class.
referential_subsets: Vec<ReferentialSubsetAllowance>Admit notes covered by caller-declared referential subsets.
modal_projection: boolAdmit landed pitch classes already exposed by a modal spine report.
derived_reservoir: boolAdmit pitch classes already present in non-structural derived material.
explicitly_foreign_material: boolAdmit pitch classes already present in explicit foreign material.