pub struct TechniquePlan { /* private fields */ }Expand description
Inspectable deployment plan composed from ordinary practice rules and deployers.
Implementations
Sourceimpl TechniquePlan
impl TechniquePlan
Sourcepub fn builder(
id: impl Into<String>,
) -> Result<TechniquePlanBuilder, SerialDeployError>
pub fn builder( id: impl Into<String>, ) -> Result<TechniquePlanBuilder, SerialDeployError>
Starts a builder for one inspectable deployment technique.
Sourcepub fn rule_specs(&self) -> Vec<PracticeRuleSpec>
pub fn rule_specs(&self) -> Vec<PracticeRuleSpec>
Returns the inspectable practice rule specifications.
Sourcepub fn deployer_specs(&self) -> Vec<SerialDeployerSpec>
pub fn deployer_specs(&self) -> Vec<SerialDeployerSpec>
Returns the inspectable deployer specifications.
Sourcepub fn practice(&self) -> SerialPractice
pub fn practice(&self) -> SerialPractice
Returns the inspectable practice carried alongside the deployers.
Sourcepub fn deploy(
&self,
rows: BTreeMap<RowInstanceId, RowForm>,
) -> Result<SerialPlan, SerialDeployError>
pub fn deploy( &self, rows: BTreeMap<RowInstanceId, RowForm>, ) -> Result<SerialPlan, SerialDeployError>
Deploys the supplied row instances into one validated immutable serial plan.