pub struct BuiltInPracticeRule { /* private fields */ }Expand description
Built-in inspectable rule implementations for common serial-practice checks.
Implementations
Sourceimpl BuiltInPracticeRule
impl BuiltInPracticeRule
Sourcepub fn aggregate(id: PracticeRuleId) -> Self
pub fn aggregate(id: PracticeRuleId) -> Self
Requires every structural ordinal to appear exactly once under the reading.
Sourcepub fn order(id: PracticeRuleId) -> Self
pub fn order(id: PracticeRuleId) -> Self
Requires first structural appearances to remain in row order.
Sourcepub fn repeats(id: PracticeRuleId) -> Self
pub fn repeats(id: PracticeRuleId) -> Self
Forbids repeated ordinal references under the reading.
Sourcepub fn doublings(id: PracticeRuleId) -> Self
pub fn doublings(id: PracticeRuleId) -> Self
Forbids simultaneous doublings of one row pitch class.
Sourcepub fn simultaneity(id: PracticeRuleId, allow: bool) -> Self
pub fn simultaneity(id: PracticeRuleId, allow: bool) -> Self
Controls whether simultaneous groups are accepted.
Sourcepub fn row_mixing(id: PracticeRuleId) -> Self
pub fn row_mixing(id: PracticeRuleId) -> Self
Forbids one event from mixing ordinals from multiple row instances.
Sourcepub fn foreign_material(id: PracticeRuleId, allow_external: bool) -> Self
pub fn foreign_material(id: PracticeRuleId, allow_external: bool) -> Self
Controls whether externally sourced material is accepted.
Sourcepub fn parameter_exhaustion(id: PracticeRuleId) -> Self
pub fn parameter_exhaustion(id: PracticeRuleId) -> Self
Requires non-structural reuse after full aggregate exposure to be declared as a relaxation.