pub struct ParameterTrack<T: ParameterValue> { /* private fields */ }Expand description
One generic named parameter track over an unchanged serial-core series.
Implementations
Sourceimpl<T: ParameterValue> ParameterTrack<T>
impl<T: ParameterValue> ParameterTrack<T>
Sourcepub fn try_new(
name: impl Into<String>,
values: Vec<T>,
exhaustion: Exhaustion,
) -> Result<Self, IntegralError>
pub fn try_new( name: impl Into<String>, values: Vec<T>, exhaustion: Exhaustion, ) -> Result<Self, IntegralError>
Constructs one exhaustive exactly-once track from a caller-declared value ladder.
Sourcepub fn try_new_with_rule(
name: impl Into<String>,
rule: AggregateRule,
values: Vec<T>,
exhaustion: Exhaustion,
) -> Result<Self, IntegralError>
pub fn try_new_with_rule( name: impl Into<String>, rule: AggregateRule, values: Vec<T>, exhaustion: Exhaustion, ) -> Result<Self, IntegralError>
Constructs one track from a caller-declared aggregate rule.
Sourcepub fn with_phase(self, phase: usize) -> Self
pub fn with_phase(self, phase: usize) -> Self
Returns this track with an explicit phase offset.
Sourcepub fn series(&self) -> &ParameterSeries<T>
pub fn series(&self) -> &ParameterSeries<T>
Returns the retained typed series.
Sourcepub const fn exhaustion(&self) -> Exhaustion
pub const fn exhaustion(&self) -> Exhaustion
Returns the configured exhaustion policy.
Sourcepub fn transformed(
&self,
transform: &SeriesTransform<ParameterAlphabet<T>>,
) -> Result<Self, IntegralError>
pub fn transformed( &self, transform: &SeriesTransform<ParameterAlphabet<T>>, ) -> Result<Self, IntegralError>
Applies a serial-core transform to this track without touching other tracks.
Sourcepub fn project(&self, plan_len: usize) -> ParameterProjection<T>
pub fn project(&self, plan_len: usize) -> ParameterProjection<T>
Projects this track against a requested integral-plan length.